@@ -73,7 +73,7 @@ impl App {
         let mut progress_interval = 0;
         loop {
             // main_activity.update_message();
-            main_activity.update_queue_items();
+            main_activity.update_playlist_items();
             if progress_interval == 0 {
                 main_activity.update_progress();
                 main_activity.run();
