@@ -1,3 +1,4 @@
+use crate::ui::activity::Loop;
 use anyhow::{anyhow, Result};
 /**
  * MIT License
@@ -31,11 +32,18 @@ pub const MUSIC_DIR: &str = "~/Music";
 #[derive(Clone, Deserialize, Serialize)]
 pub struct Termusic {
     pub music_dir: String,
+    #[serde(skip_serializing)]
+    pub music_dir_from_cli: Option<String>,
+    pub loop_mode: Loop,
+    pub volume: i32,
 }
 impl Default for Termusic {
     fn default() -> Self {
         Self {
             music_dir: MUSIC_DIR.to_string(),
+            music_dir_from_cli: None,
+            loop_mode: Loop::Queue,
+            volume: 70,
         }
     }
 }
@@ -52,7 +60,7 @@ impl Termusic {
         Ok(())
     }
 
-    pub fn load() -> Result<Self> {
+    pub fn load(&mut self) -> Result<()> {
         let mut path = get_app_config_path()?;
         path.push("config.toml");
         if !path.exists() {
@@ -62,7 +70,8 @@ impl Termusic {
 
         let string = read_to_string(path.to_string_lossy().as_ref())?;
         let config: Self = toml::from_str(&string)?;
-        Ok(config)
+        *self = config;
+        Ok(())
     }
 }
 
