@@ -28,8 +28,8 @@
 // Submodules
 // mod actions;
 // mod config;
+mod library;
 mod playlist;
-mod queue;
 mod update;
 mod view;
 mod youtube_options;
@@ -55,9 +55,9 @@ use youtube_options::YoutubeOptions;
 // -- components
 const COMPONENT_LABEL_HELP: &str = "LABEL_HELP";
 const COMPONENT_PARAGRAPH_LYRIC: &str = "PARAGRAPH_LYRIC";
-const COMPONENT_TABLE_QUEUE: &str = "SCROLLTABLE_QUEUE";
+const COMPONENT_TABLE_PLAYLIST: &str = "SCROLLTABLE_PLAYLIST";
 const COMPONENT_TABLE_YOUTUBE: &str = "SCROLLTABLE_YOUTUBE";
-const COMPONENT_TREEVIEW: &str = "TREEVIEW";
+const COMPONENT_TREEVIEW_LIBRARY: &str = "TREEVIEW";
 const COMPONENT_PROGRESS: &str = "PROGRESS";
 const COMPONENT_TEXT_HELP: &str = "TEXT_HELP";
 const COMPONENT_INPUT_URL: &str = "INPUT_URL";
@@ -65,8 +65,8 @@ const COMPONENT_TEXT_ERROR: &str = "TEXT_ERROR";
 const COMPONENT_CONFIRMATION_RADIO: &str = "CONFIRMATION_RADIO";
 const COMPONENT_CONFIRMATION_INPUT: &str = "CONFIRMATION_INPUT";
 const COMPONENT_TEXT_MESSAGE: &str = "TEXT_MESSAGE";
-const COMPONENT_SEARCH_PLAYLIST_TABLE: &str = "SEARCH_PLAYLIST_LIST";
-const COMPONENT_SEARCH_PLAYLIST_INPUT: &str = "SEARCH_PLAYLIST_INPUT";
+const COMPONENT_TABLE_SEARCH_LIBRARY: &str = "SEARCH_LIBRARY_TABLE";
+const COMPONENT_INPUT_SEARCH_LIBRARY: &str = "SEARCH_LIBRARY_INPUT";
 
 /// ### `ViewLayout`
 ///
@@ -82,7 +82,7 @@ pub struct TermusicActivity {
     path: PathBuf,
     tree: Tree,
     pub player: GStreamer,
-    queue_items: VecDeque<Song>,
+    playlist_items: VecDeque<Song>,
     time_pos: u64,
     pub status: Option<Status>,
     pub current_song: Option<Song>,
@@ -91,8 +91,8 @@ pub struct TermusicActivity {
     yanked_node_id: Option<String>,
     config: Termusic,
     youtube_options: YoutubeOptions,
-    sender_queueitems: Sender<VecDeque<Song>>,
-    receiver_queueitems: Receiver<VecDeque<Song>>,
+    sender_playlist_items: Sender<VecDeque<Song>>,
+    receiver_playlist_items: Receiver<VecDeque<Song>>,
 }
 
 #[derive(Clone, Copy)]
@@ -136,6 +136,7 @@ impl Default for TermusicActivity {
         let p: &Path = Path::new(full_path.as_ref());
         let (tx, rx): (Sender<UpdateComponents>, Receiver<UpdateComponents>) = mpsc::channel();
         let (tx2, rx2): (Sender<VecDeque<Song>>, Receiver<VecDeque<Song>>) = mpsc::channel();
+        let config = Termusic::default();
         Self {
             exit_reason: None,
             context: None,
@@ -144,17 +145,17 @@ impl Default for TermusicActivity {
             tree: Tree::new(Self::dir_tree(p, 3)),
             path: p.to_path_buf(),
             player: GStreamer::new(),
-            queue_items: VecDeque::with_capacity(100),
+            playlist_items: VecDeque::with_capacity(100),
             time_pos: 0,
             status: None,
             current_song: None,
             sender: tx,
             receiver: rx,
             yanked_node_id: None,
-            config: Termusic::default(),
+            config,
             youtube_options: YoutubeOptions::new(),
-            sender_queueitems: tx2,
-            receiver_queueitems: rx2,
+            sender_playlist_items: tx2,
+            receiver_playlist_items: rx2,
         }
     }
 }
@@ -162,15 +163,22 @@ impl Default for TermusicActivity {
 impl TermusicActivity {
     pub fn init_config(&mut self, config: &Termusic) {
         self.config = config.clone();
-        let music_dir = self.config.music_dir.clone();
-        let full_path = shellexpand::tilde(&music_dir);
-        let p: &Path = Path::new(full_path.as_ref());
-        self.scan_dir(p);
+        if let Some(music_dir) = self.config.music_dir_from_cli.clone() {
+            let full_path = shellexpand::tilde(&music_dir);
+            let p: &Path = Path::new(full_path.as_ref());
+            self.scan_dir(p);
+        } else {
+            let music_dir = self.config.music_dir.clone();
+            let full_path = shellexpand::tilde(&music_dir);
+            let p: &Path = Path::new(full_path.as_ref());
+            self.scan_dir(p);
+        }
+        self.player.set_volume(self.config.volume);
     }
     pub fn run(&mut self) {
         match self.status {
             Some(Status::Stopped) => {
-                if self.queue_items.is_empty() {
+                if self.playlist_items.is_empty() {
                     return;
                 }
                 self.status = Some(Status::Running);
@@ -183,7 +191,9 @@ impl TermusicActivity {
 
     pub fn run_tageditor(&mut self) {
         let mut tageditor: TagEditorActivity = TagEditorActivity::default();
-        if let Some(Payload::One(Value::Str(node_id))) = self.view.get_state(COMPONENT_TREEVIEW) {
+        if let Some(Payload::One(Value::Str(node_id))) =
+            self.view.get_state(COMPONENT_TREEVIEW_LIBRARY)
+        {
             let p: &Path = Path::new(node_id.as_str());
             if p.is_dir() {
                 self.mount_error("directory doesn't have tag!");
@@ -222,7 +232,7 @@ impl TermusicActivity {
             }
             if let Some(ExitReason::NeedRefreshPlaylist(file)) = tageditor.will_umount() {
                 // print!("{}", file);
-                self.sync_playlist(Some(file));
+                self.sync_library(Some(file));
                 self.update_item_delete();
             }
 
@@ -257,8 +267,8 @@ impl Activity for TermusicActivity {
         // // Init view
         self.init_setup();
 
-        if let Err(err) = self.load_queue() {
-            error!("Failed to save queue: {}", err);
+        if let Err(err) = self.load_playlist() {
+            error!("Failed to load playlist: {}", err);
         }
         self.status = Some(Status::Stopped);
     }
@@ -279,7 +289,7 @@ impl Activity for TermusicActivity {
             self.redraw = true;
             // Handle event
             let msg = self.view.on(event);
-            self.update(msg);
+            self.update(&msg);
         }
         // }
         // Redraw if necessary
@@ -306,8 +316,11 @@ impl Activity for TermusicActivity {
     /// This function must be called once before terminating the activity.
     /// This function finally releases the context
     fn on_destroy(&mut self) -> Option<Context> {
-        if let Err(err) = self.save_queue() {
-            error!("Failed to save queue: {}", err);
+        if let Err(err) = self.save_playlist() {
+            error!("Failed to save playlist: {}", err);
+        }
+        if let Err(err) = self.config.save() {
+            error!("Failed to save config: {}", err);
         }
         // Disable raw mode
         if let Err(err) = disable_raw_mode() {
