@@ -21,11 +21,14 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-use super::{TermusicActivity, UpdateComponents, COMPONENT_TABLE_YOUTUBE, COMPONENT_TREEVIEW};
+use super::{
+    TermusicActivity, UpdateComponents, COMPONENT_TABLE_YOUTUBE, COMPONENT_TREEVIEW_LIBRARY,
+};
 use crate::invidious::{Instance, YoutubeVideo};
 use anyhow::{anyhow, bail, Result};
 use humantime::format_duration;
 use id3::frame::Lyrics;
+use if_chain::if_chain;
 use lazy_static::lazy_static;
 use regex::Regex;
 use std::path::{Path, PathBuf};
@@ -119,10 +122,12 @@ impl TermusicActivity {
                         page: 1,
                         invidious_instance: instance,
                     };
-                    let _drop = tx.send(UpdateComponents::YoutubeSearchSuccess(youtube_options));
+                    tx.send(UpdateComponents::YoutubeSearchSuccess(youtube_options))
+                        .ok();
                 }
                 Err(e) => {
-                    let _drop = tx.send(UpdateComponents::YoutubeSearchFail(e.to_string()));
+                    tx.send(UpdateComponents::YoutubeSearchFail(e.to_string()))
+                        .ok();
                 }
             },
         );
@@ -154,7 +159,7 @@ impl TermusicActivity {
                     )
                     .build();
                 let msg = self.view.update(COMPONENT_TABLE_YOUTUBE, props);
-                self.update(msg);
+                self.update(&msg);
             }
             return;
         }
@@ -196,7 +201,9 @@ impl TermusicActivity {
     #[allow(clippy::too_many_lines)]
     pub fn youtube_dl(&mut self, link: &str) -> Result<()> {
         let mut path: PathBuf = PathBuf::new();
-        if let Some(Payload::One(Value::Str(node_id))) = self.view.get_state(COMPONENT_TREEVIEW) {
+        if let Some(Payload::One(Value::Str(node_id))) =
+            self.view.get_state(COMPONENT_TREEVIEW_LIBRARY)
+        {
             let p: &Path = Path::new(node_id.as_str());
             if p.is_dir() {
                 path = PathBuf::from(p);
@@ -222,7 +229,7 @@ impl TermusicActivity {
         let tx = self.sender.clone();
 
         thread::spawn(move || -> Result<()> {
-            let _drop = tx.send(UpdateComponents::DownloadRunning);
+            tx.send(UpdateComponents::DownloadRunning).ok();
             // start download
             let download = ytd.download();
 
@@ -242,7 +249,7 @@ impl TermusicActivity {
                             if let Some(p_base) = p.file_stem() {
                                 t.set_title(p_base.to_string_lossy());
                             }
-                            let _drop = t.write_to_path(p, id3::Version::Id3v24);
+                            t.write_to_path(p, id3::Version::Id3v24).ok();
                             t
                         };
 
@@ -251,59 +258,60 @@ impl TermusicActivity {
                             for f in files.flatten() {
                                 let name = f.file_name().clone();
                                 let p = Path::new(&name);
-                                if let Some(ext) = p.extension() {
-                                    if ext == "lrc" {
-                                        if let Some(stem_lrc) = p.file_stem() {
-                                            let p1: &Path = Path::new(&file_fullname);
-                                            if let Some(p_base) = p1.file_stem() {
-                                                if stem_lrc
-                                                    .to_string_lossy()
-                                                    .to_string()
-                                                    .contains(p_base.to_string_lossy().as_ref())
-                                                {
-                                                    let mut lang_ext = "eng".to_string();
-                                                    if let Some(p_short) = p.file_stem() {
-                                                        let p2 = Path::new(p_short);
-                                                        if let Some(ext2) = p2.extension() {
-                                                            lang_ext =
-                                                                ext2.to_string_lossy().to_string();
-                                                        }
-                                                    }
-                                                    let lyric_string =
-                                                        std::fs::read_to_string(f.path());
-                                                    id3_tag.add_lyrics(Lyrics {
-                                                        lang: "eng".to_string(),
-                                                        description: lang_ext,
-                                                        text: lyric_string.unwrap_or_else(|_| {
-                                                            String::from("[00:00:01] No lyric")
-                                                        }),
-                                                    });
-                                                    let _drop = std::fs::remove_file(f.path());
-                                                }
+                                if_chain! {
+                                    if let Some(ext) = p.extension();
+                                    if ext == "lrc";
+                                    if let Some(stem_lrc) = p.file_stem();
+                                    let p1: &Path = Path::new(&file_fullname);
+                                    if let Some(p_base) = p1.file_stem();
+                                    if stem_lrc
+                                        .to_string_lossy()
+                                        .to_string()
+                                        .contains(p_base.to_string_lossy().as_ref());
+
+                                    then {
+                                        let mut lang_ext = "eng".to_string();
+                                        if let Some(p_short) = p.file_stem() {
+                                            let p2 = Path::new(p_short);
+                                            if let Some(ext2) = p2.extension() {
+                                                lang_ext =
+                                                    ext2.to_string_lossy().to_string();
                                             }
                                         }
+                                        let lyric_string =
+                                            std::fs::read_to_string(f.path());
+                                        id3_tag.add_lyrics(Lyrics {
+                                            lang: "eng".to_string(),
+                                            description: lang_ext,
+                                            text: lyric_string.unwrap_or_else(|_| {
+                                                String::from("[00:00:01] No lyric")
+                                            }),
+                                        });
+                                        std::fs::remove_file(f.path()).ok();
                                     }
                                 }
                             }
                         }
 
-                        let _drop = id3_tag.write_to_path(&file_fullname, id3::Version::Id3v24);
+                        id3_tag
+                            .write_to_path(&file_fullname, id3::Version::Id3v24)
+                            .ok();
 
-                        let _drop = tx.send(UpdateComponents::DownloadSuccess);
+                        tx.send(UpdateComponents::DownloadSuccess).ok();
                         sleep(Duration::from_secs(5));
-                        let _drop =
-                            tx.send(UpdateComponents::DownloadCompleted(Some(file_fullname)));
+                        tx.send(UpdateComponents::DownloadCompleted(Some(file_fullname)))
+                            .ok();
                     } else {
                         // This shoudn't happen unless the output format of youtubedl changed
-                        let _drop = tx.send(UpdateComponents::DownloadSuccess);
+                        tx.send(UpdateComponents::DownloadSuccess).ok();
                         sleep(Duration::from_secs(5));
-                        let _drop = tx.send(UpdateComponents::DownloadCompleted(None));
+                        tx.send(UpdateComponents::DownloadCompleted(None)).ok();
                     }
                 }
                 ResultType::IOERROR | ResultType::FAILURE => {
-                    let _drop = tx.send(UpdateComponents::DownloadErrDownload);
+                    tx.send(UpdateComponents::DownloadErrDownload).ok();
                     sleep(Duration::from_secs(5));
-                    let _drop = tx.send(UpdateComponents::DownloadCompleted(None));
+                    tx.send(UpdateComponents::DownloadCompleted(None)).ok();
                 }
             }
             Ok(())
