@@ -146,7 +146,7 @@ impl Activity for TagEditorActivity {
             self.redraw = true;
             // Handle event
             let msg = self.view.on(event);
-            self.update(msg);
+            self.update(&msg);
         }
         // }
 
